A redirect policy. Called before each redirect is followed, with the
request about to be made and via, the chain of requests already made
(oldest first). Return RedirectPolicy::Follow to continue,
RedirectPolicy::UseLastResponse to stop and return the last response,
or an Err to abort the request with that error.