pub struct Header(/* private fields */);Expand description
HTTP headers — a multi-valued map with case-insensitive canonical keys.
Keys are stored in canonical form (“Content-Type”, not “content-type”).
Mirrors Go’s http.Header.
Implementations
Sourceimpl Header
impl Header
pub fn new() -> Self
Sourcepub fn canonical_key(s: &str) -> String
pub fn canonical_key(s: &str) -> String
Canonical form of a header key: “content-type” → “Content-Type”.
Sourcepub fn set(&mut self, key: &str, value: impl Into<String>)
pub fn set(&mut self, key: &str, value: impl Into<String>)
Set the key to a single value, replacing any existing values.
Sourcepub fn add(&mut self, key: &str, value: impl Into<String>)
pub fn add(&mut self, key: &str, value: impl Into<String>)
Add a value to the key without replacing existing values.