Server

Struct Server 

pub struct Server {
    pub addr: String,
    pub handler: Option<Arc<dyn Handler>>,
    pub read_timeout: Option<Duration>,
    pub write_timeout: Option<Duration>,
    pub idle_timeout: Option<Duration>,
    pub max_header_bytes: usize,
    /* private fields */
}
An HTTP/1.1 server. Mirrors Go’s http.Server.

Fields

addr: String

TCP address to listen on, e.g. "127.0.0.1:8080".

handler: Option<Arc<dyn Handler>>

Request handler. None uses the global DefaultServeMux.

read_timeout: Option<Duration>write_timeout: Option<Duration>idle_timeout: Option<Duration>max_header_bytes: usize

Maximum bytes consumed while reading request headers.

Implementations

Source

impl Server

pub fn new(addr: impl Into<String>) -> Self

pub fn listen_and_serve(&self) -> Result<(), HttpError>

Bind, listen, and serve HTTP/1.1 requests.

Must be called from within a #[go_lib::main] body (goroutine context).

Blocks the calling goroutine until shutdown() is called or a fatal listener error occurs. Port of Go’s (*Server).ListenAndServe.

pub fn listen_and_serve_tls( &self, cert_file: &str, key_file: &str, ) -> Result<(), HttpError>

Bind, listen, and serve HTTPS/1.1 requests.

Equivalent to listen_and_serve but wraps each accepted connection in a TLS session using the certificate and key loaded from cert_file and key_file (PEM format).

Must be called from within a #[go_lib::main] body (goroutine context). Port of Go’s (*Server).ListenAndServeTLS.

pub fn shutdown(&self)

Signal the server to stop accepting new connections. Port of Go’s (*Server).Shutdown (simplified).